@@ -109,7 +109,7 @@ class NonFileStreamReader:
         self.eof = not data
         return data
 
-    async def __aiter__(self):
+    def __aiter__(self):
         return self
 
     async def __anext__(self):
@@ -140,7 +140,7 @@ class NonFileStreamWriter:
             await self.loop.run_in_executor(None, flush)
 
 
-async def open_stantard_pipe_connection(pipe_in, pipe_out, pipe_err, *, loop=None):
+async def open_standard_pipe_connection(pipe_in, pipe_out, pipe_err, *, loop=None):
     if loop is None:
         loop = asyncio.get_event_loop()
     # Reader
@@ -161,7 +161,7 @@ async def open_stantard_pipe_connection(pipe_in, pipe_out, pipe_err, *, loop=Non
 
 async def create_standard_streams(stdin, stdout, stderr, *, loop=None):
     if all(map(is_pipe_transport_compatible, (stdin, stdout, stderr))):
-        return await open_stantard_pipe_connection(stdin, stdout, stderr, loop=loop)
+        return await open_standard_pipe_connection(stdin, stdout, stderr, loop=loop)
     return (
         NonFileStreamReader(stdin, loop=loop),
         NonFileStreamWriter(stdout, loop=loop),
